# Foobar

 You can safely message with the ondokuz program.


## Installation



```bash
pip install ondokuz
```

## Usage

```
import ondokuz
ondokuz.tr()


```



## License
[MIT](https://choosealicense.com/licenses/mit/)
